%global debug_package %{nil}

Name: docker-engine
Version: %{_version}
Release: 13%{?dist}

Source0: engine.tgz
Source1: docker.service
Source2: docker.socket
Summary: The open-source application container engine
Group: Tools/Docker
License: ASL 2.0
URL: https://dockerproject.org
Vendor: Docker
Packager: Oracle America

# required packages on install
Requires: docker-cli
Requires: container-selinux >= 2:2.77
Requires: libseccomp >= 2.3
Requires: systemd-units
Requires: iptables
Requires: containerd >= 1.4.8
Requires: runc >= 3:1.0.0-1.rc95
Requires: libcgroup
Requires: tar
Requires: xz

# Resolves: rhbz#1165615
Requires: device-mapper-libs >= 1.02.90-1

BuildRequires: which
BuildRequires: make
BuildRequires: gcc
BuildRequires: pkgconfig(systemd)
BuildRequires: golang >= 1.15

# conflicting packages
Conflicts: docker-io
Conflicts: docker-engine-cs
Conflicts: docker-ee

# Obsolete packages
Obsoletes: docker < 1.6.1-2.0.1.el7
Provides: docker = %{_version}-%{_release}%{?dist}

%description
Docker is an open source project to build, ship and run any application as a
lightweight container.

Docker containers are both hardware-agnostic and platform-agnostic. This means
they can run anywhere, from your laptop to the largest EC2 compute instance and
everything in between - and they don't require you to use a particular
language, framework or packaging system. That makes them great building blocks
for deploying and scaling web apps, databases, and backend services without
depending on a particular stack or provider.

%prep
%setup -q -c -n src -a 0

%build
export DOCKER_GITCOMMIT=%{_gitcommit}
mkdir -p /go/src/github.com/docker
ln -s /root/rpmbuild/BUILD/src/engine /go/src/github.com/docker/docker

pushd engine
for component in tini "proxy dynamic";do
    TMP_GOPATH="/go" hack/dockerfile/install/install.sh $component
done
VERSION=%{_origversion} PRODUCT=docker hack/make.sh dynbinary
popd

%check
engine/bundles/dynbinary-daemon/dockerd -v

%install
# install daemon binary
install -D -p -m 0755 $(readlink -f engine/bundles/dynbinary-daemon/dockerd) $RPM_BUILD_ROOT/%{_bindir}/dockerd

# install proxy
install -D -p -m 0755 /usr/local/bin/docker-proxy $RPM_BUILD_ROOT/%{_bindir}/docker-proxy

# install tini
install -D -p -m 755 /usr/local/bin/docker-init $RPM_BUILD_ROOT/%{_bindir}/docker-init

# install systemd scripts
install -D -m 0644 %{_topdir}/SOURCES/docker.service $RPM_BUILD_ROOT/%{_unitdir}/docker.service
install -D -m 0644 %{_topdir}/SOURCES/docker.socket $RPM_BUILD_ROOT/%{_unitdir}/docker.socket

mkdir -p build-docs
for engine_file in AUTHORS CHANGELOG.md CONTRIBUTING.md LICENSE MAINTAINERS NOTICE README.md; do
    cp "engine/$engine_file" "build-docs/engine-$engine_file"
done

%files
%doc build-docs/engine-AUTHORS build-docs/engine-CHANGELOG.md build-docs/engine-CONTRIBUTING.md build-docs/engine-LICENSE build-docs/engine-MAINTAINERS build-docs/engine-NOTICE build-docs/engine-README.md
/%{_bindir}/dockerd
/%{_bindir}/docker-proxy
/%{_bindir}/docker-init
/%{_unitdir}/docker.service
/%{_unitdir}/docker.socket
%license build-docs/engine-LICENSE

%pre
if [ $1 -gt 0 ] ; then
    # package upgrade scenario, before new files are installed

    # clear any old state
    rm -f %{_localstatedir}/lib/rpm-state/docker-is-active > /dev/null 2>&1 || :

    # check if docker service is running
    if systemctl is-active docker > /dev/null 2>&1; then
        systemctl stop docker > /dev/null 2>&1 || :
        touch %{_localstatedir}/lib/rpm-state/docker-is-active > /dev/null 2>&1 || :
    fi
fi

%post
%systemd_post docker
if ! getent group docker > /dev/null; then
    groupadd --system docker
fi
if [ $1 -eq 1 ]; then
    # For a new install only, if /var/lib/docker is (or will be) mounted on
    # xfs with ftype == 0 then force 'devicemapper' (orabug: 25995797)
    for m in /var/lib/docker /var/lib ; do
        if [ -d $m ] ; then
            if [ $(stat -f -c %T $m) == xfs ] && /sbin/xfs_info $m | grep --quiet 'ftype=0' ; then
                cat << EOF >> /%{_sysconfdir}/sysconfig/docker-storage
DOCKER_STORAGE_OPTIONS= --storage-driver devicemapper --storage-opt dm.basesize=25G
EOF
            fi
            break
        fi
    done
fi

%preun
%systemd_preun docker

%postun
%systemd_postun_with_restart docker

%posttrans
if [ $1 -ge 0 ] ; then
    # package upgrade scenario, after new files are installed
    # check if docker was running before upgrade
    if [ -f %{_localstatedir}/lib/rpm-state/docker-is-active ]; then
        systemctl start docker > /dev/null 2>&1 || :
        rm -f %{_localstatedir}/lib/rpm-state/docker-is-active > /dev/null 2>&1 || :
    fi
fi

%changelog
* Thu Jul 22 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-13
- updated containerd minimum version to 1.4.8 to address CVE-2021-32760.

* Fri Jul 09 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-12
- Addressed oraBug 33099096 docker: Error response from daemon: unable to find user 0: invalid argument.  

* Thu Jun 24 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-11
- Addresses CVE-2021-30465 - updated runc minimum version to runc >= 3:1.0.0-1.rc95.

* Tue Jun 22 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-10
- Addresses runc CVE-2021-30465 - updated runc versions in cli/vendor.conf and docker-engine/vendor.conf to 1.0.0-rc95.

* Mon Apr 12 2021 <luis.daniel.carvallo@oracle.com> 19.03.11-9
- Bugfix for "docker pull" from private repo fails after successful login

* Wed Feb 10 2021 <michael.a.thompson@oracle.com> 19.03.11-8
- Patch for missing engine license file

* Thu Dec 3 2020 <michael.a.thompson@oracle.com> 19.03.11-7
- Fix for CVE-2020-15257

* Fri Oct 16 2020 <michael.a.thompson@oracle.com> 19.03.11-6
- Fix for CVE-2020-15157

* Tue Aug 18 2020 <michael.a.thompson@oracle.com> 19.03.11-5
- Bugfix for "docker images [name]" not working on docker 19.03.11-ol
- Address CVE-2020-16845

* Thu Jun 18 2020 <michael.a.thompson@oracle.com> 19.03.11-4
- added patch for registry list

* Tue Jun 2 2020 <michael.a.thompson@oracle.com> 19.03.11-3
- update to 19.03.11 for CVE-2020-13401

* Tue Jul 30 2019 <michael.calunod@oracle.com> 19.03.1-1.0.0
- update to 19.03.1

* Thu Jul 25 2019 <michael.calunod@oracle.com> 19.03-0.0.1
- update to 19.03

* Tue May 14 2019 <michael.calunod@oracle.com> 18.09.1-1.0.6
- disable kmem accounting for UEKR4

* Mon Feb 11 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.5
- apply e4931e664feac6fa8846f3f04268a0cc98822549, fixes CVE-2019-5736

* Sun Feb 10 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.4
- fix authentication error when using docker hub and using --default-registry

* Sat Feb  9 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.3
- fix authentication errors when using docker hub

* Thu Feb  7 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.2
- use epoch in container-selinux dependency

* Thu Feb  7 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.1
- fix "docker cp doesn't work for btrfs" (OLM-158)
- update build to Go 1.10.8

* Tue Feb  5 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.0
- update to 18.09.1

* Wed Jan  9 2019 <laszlo.peter@oracle.com> 18.09-1.0.0
- rename back to docker-engine, rename dockerd-ce to dockerd and stop
  using alternatives

* Wed Sep 26 2018 <laszlo.peter@oracle.com> 18.09-0.0.1
- merge docker-engine.spec changes by Oracle into docker-ce.spec from upstream
  18.09 branch

* Wed Aug  8 2018 <laszlo.peter@oracle.com> 18.03.1.ol-0.0.7
- fix [orabug 28452214] and [orabug 28461404]

* Fri Jul 27 2018 <laszlo.peter@oracle.com> 18.03.1.ol-0.0.6
- obsolete/provide the docker package [orabug 28216396]
- Fix docker plugin reference resolution [orabug 28376247]

* Thu Jul 26 2018 <wiekus.beukes@oracle.com> 18.03.1.ol-1.0.4
- Fixed issue where RPM overwrites config files

* Wed Jan 03 2018 <jesse.butler@oracle.com> 17.12.0.ol-1.0.1
- Update docker-engine package for upstream 17.12.0

* Tue Dec 19 2017 <jesse.butler@oracle.com> 17.09.1.ol-1.0.2
- Update docker-engine package for upstream 17.09.1

* Thu Oct 05 2017 <jesse.butler@oracle.com> 17.06.2.ol-1.0.1
- Update docker-engine package for upstream 17.06.2 [orabug 26673768]
- Migrate to new "ol"-based versioning
- add docker-storage-config utility

* Tue Mar 28 2017 <jesse.butler@oracle.com> 17.03.1-ce-3.0.1
- Update docker-engine package for upstream 17.03.1
- Enable configuration of Docker daemon via sysconfig [orabug 21804877]
- Require UEK4 for docker 1.9 [orabug 22235639 22235645]
- Add docker.conf for prelink [orabug 25147708]
- Update oracle linux selinux policy to match upstream [orabug 25653794]
- Use dockerd instead of docker daemon as it is deprecated [orabug 25653794]
